@@ -8,7 +8,7 @@ import re
 class ArgUtils(object):
 
 	@staticmethod
-	def wrapWords(text, width):
+	def wrapWords(text, width) -> list:
 		assert isinstance(text, str)
 		assert isinstance(width, int)
 
@@ -34,8 +34,6 @@ class ArgUtils(object):
 		return data
 	#
 
-
-
 	@staticmethod
 	def createEmptyString(length):
 		sb = ""
@@ -44,8 +42,6 @@ class ArgUtils(object):
 		return sb
 	#
 
-
-
 	@staticmethod
 	def writePrefixedWrappingText(firstLine, text, width, outputList):
 		if firstLine is None:
@@ -63,8 +59,6 @@ class ArgUtils(object):
 				outputList.append(spaces + line)
 	#
 
-
-
 #
 
 
